==> kbibtex_0.1.5.orig.tar.gz: kbibtex-0.1.5/src/encoder.h <==
/***************************************************************************
*   Copyright (C) 2004-2006 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXENCODER_H
#define BIBTEXENCODER_H

#include <entryfield.h>

class QString;

namespace BibTeX
{

    /**
    @author Thomas Fischer
    */
    class Encoder
    {
    public:
        Encoder();
        virtual ~Encoder();

        virtual QString decode( const QString & /*text*/ ) { return QString::null;};
        virtual QString encode( const QString & /*text*/ ) { return QString::null;};
        virtual QString decodeSpecialized( const QString & /*text*/, const EntryField::FieldType /*fieldType*/ = EntryField::ftUnknown ) { return QString::null; };
        virtual QString encodeSpecialized( const QString & /*text*/, const EntryField::FieldType /*fieldType*/ = EntryField::ftUnknown ) { return QString::null; };
    };

}

#endif

==> kbibtex_0.2.2.orig.tar.gz: kbibtex-0.2.2/src/encoder.h <==
/***************************************************************************
*   Copyright (C) 2004-2006 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXENCODER_H
#define BIBTEXENCODER_H

#include <entryfield.h>

class QString;

namespace BibTeX
{

    /**
    @author Thomas Fischer
    */
    class Encoder
    {
    public:
        virtual ~Encoder() { /* nothing */};

        virtual QString decode( const QString & /*text*/ )
        {
            return QString::null;
        };
        virtual QString encode( const QString & /*text*/ )
        {
            return QString::null;
        };
        virtual QString encodeSpecialized( const QString & /*text*/, const EntryField::FieldType /*fieldType*/ = EntryField::ftUnknown )
        {
            return QString::null;
        };
    };

}

#endif
